package Dist::Zilla::Plugin::Prereq;
our $VERSION = '1.004';

# ABSTRACT: list simple prerequisites
use Moose;
with 'Dist::Zilla::Role::FixedPrereqs';


has _prereq => (
  is   => 'ro',
  isa  => 'HashRef',
  default => sub { {} },
);

sub new {
  my ($class, $arg) = @_;

  my $self = $class->SUPER::new({
    '=name' => delete $arg->{'=name'},
    zilla   => delete $arg->{zilla},
    _prereq => $arg,
  });
}

sub prereq { shift->_prereq }

no Moose;
__PACKAGE__->meta->make_immutable;
1;

__END__

=pod

=head1 NAME

Dist::Zilla::Plugin::Prereq - list simple prerequisites

=head1 VERSION

version 1.004

=head1 SYNOPSIS

In your F<dist.ini>:

    [Prereq]
    Foo::Bar = 1.002
    MRO::Compat = 10
    Sub::Exporter = 0

=head1 DESCRIPTION

This module adds "fixed" prerequisites to your distribution.  These are prereqs
with a known, fixed minimum version that doens't change based on platform or
other conditions.

=head1 AUTHOR

  Ricardo SIGNES <rjbs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2009 by Ricardo SIGNES.

This is free software; you can redistribute it and/or modify it under
the same terms as perl itself.

=cut 


